package com.seeshiontech.vecloudsdk;

import com.alibaba.fastjson.JSON;
import java.util.HashMap;

/**
 *   按时长计费SDK，用户必须通过此类设置参数，检查参数，提交渲染
 *   接口文档 http://www.seeshiontech.com/docs/page_12.html
 * */

public class Cpr extends Request {

    String remoteUrl = "/render/charge/cpr/request";
    private HashMap<String, Object> taskData;

    public HashMap<String, String> cprApiRule = new HashMap<String, String>() {{
        put("tplId", "required|int");
        put("tplType", "required|int");
        put("tplVersion", "required|int");
        put("tplUrl", "required|string");
        put("recordId", "required|string");
        put("assetUrls", "any|array");
        put("replaceableJson", "any|array");
        put("musicUrl", "any|string");
        put("musicLoop", "any|int");
        put("subAssetUrls", "any|array");
        put("ossId", "required|string");
        put("notifyUrl", "required|string");
        put("uploadKey", "required|string|^\\/.*"); // Upload Key 不能以/开头
        put("audioTracks", "any|array");
        put("setting", "any|int");
    }};

    public Cpr(Config config) {
        super(config);
    }

    public HashMap<String, Object> getTaskData() {
        return taskData;
    }

    public String submit() {
        String taskJson = (JSON.toJSONString(this.taskData));
        return super.submitTask(taskJson, remoteUrl);
    }


    /**
     * 设置CPR任务数据，如果任务参数有错误，会抛出异常
     * */
    public boolean setTaskData(HashMap<String, Object> taskData) throws Exception {
        taskData.put("ossId", config.getOssId());
        boolean check =  checkParamValid(taskData, this.cprApiRule);
        if (check) {
            //如果检查通过，cpr接口还需要对【assetUrls 和 replaceableJson其中之一必须含有值】进行检查
            if (taskData.get("replaceableJson") == null && taskData.get("assetUrls") == null)
            {
                throw new Exception("replaceableJson & assetUrls one of them must have value");
            }
            this.taskData = taskData;
        }
        return check;
    }
}
